Skip to contents

These four functions adjust the stacking order of a page element on its slide using the Google Slides UpdatePageElementsZOrderRequest.

Usage

send_to_front(element)

send_to_back(element)

send_forward(element)

send_backward(element)

Arguments

element

An object of class element.

Value

The element object, invisibly.