Add a linked Google Sheets chart to a Google Slides presentation
Source:R/add_chart.R
add_linked_chart.RdAdd a linked Google Sheets chart to a Google Slides presentation
Usage
add_linked_chart(
chart_obj,
slide_obj,
position,
linked = TRUE,
order = c("front", "back"),
token = NULL,
call = rlang::caller_env()
)Arguments
- chart_obj
A Google Sheets chart object
- slide_obj
A Google Slides slide object
- position
An object of class `r2slides::slide_position`
- linked
Optional. A logical indicating whether the chart should be linked. Default: `TRUE`.
- order
Optional. One of `"front"` or `"back"`. Controls the Z-order of the created chart element. Default: `"front"`.
- token
Optional. An OAuth2 token. The default uses `r2slides_token()` to find a token.
- call
Optional. Call environment used in error messages.