Returns the axis-aligned bounding box that contains one or more slide_position objects, accounting for rotation.
Details
When objects are rotated, their actual occupied space extends beyond their intrinsic width and height. This function calculates the smallest axis-aligned rectangle that contains all provided objects, including any rotation.
All objects must have the same slide_size (slide_width and slide_height).