These four functions adjust the stacking order of a page element on its slide using the Google Slides [UpdatePageElementsZOrderRequest](https://developers.google.com/workspace/slides/api/reference/rest/v1/presentations/request#updatepageelementszorderrequest).