Skip to contents

Text styling properties

Usage

text_style(
  bg_color = NULL,
  text_color = NULL,
  bold = NULL,
  italic = NULL,
  font_family = NULL,
  font_size = NULL,
  link = NULL,
  baseline_offset = NULL,
  small_caps = NULL,
  strikethrough = NULL,
  underline = NULL
)

Arguments

bg_color

A list specifying background color (RGB).

text_color

A list specifying text color (RGB).

bold

A logical indicating whether the text should be bold.

italic

A logical indicating whether the text should be italic.

font_family

A string specifying the font family.

font_size

A numeric specifying the font size in points.

A string specifying the link URL.

baseline_offset

A numeric specifying the baseline offset in points.

small_caps

A logical indicating whether the text should be in small caps.

strikethrough

A logical indicating whether the text should be strikethrough.

underline

A logical indicating whether the text should be underlined.